@@ -806,9 +806,11 @@ periodic_cleanup_timeout(gpointer data)
       gconf_log (GCL_INFO, _("SIGHUP received, reloading all databases"));
 
       need_db_reload = FALSE;
+      logfile_save ();
       shutdown_databases ();
       init_databases ();
-      gconf_server_load_sources ();		  
+      gconf_server_load_sources ();
+      logfile_read ();
     }
   
   gconf_log (GCL_DEBUG, "Performing periodic cleanup, expiring cache cruft");
@@ -1021,6 +1023,12 @@ drop_old_databases(void)
     {
       GConfDatabase* db = tmp_list->data;
 
+      if (db == default_db)
+	{
+	  tmp_list = g_list_next (tmp_list);
+	  continue;
+	}
+
       /* Drop any listeners whose clients are gone. */
       gconf_database_drop_dead_listeners (db);
       
